#ifndef INCLUDED_SPREAD_
#define INCLUDED_SPREAD_


#include "../globals/globals.h"

class Spread: public Globals
{
    protected: 

        // in the original code refreshing is handled by reloading the
        // complete config file. So the argument passed to this member should
        // be the initial values and not the updated values.

        static double refresh(double orgValue, double orgSpread, 
                              uint16_t distribution);
};
        
#endif
